==> v0.1.81-snapshot.tar.gz: beteran-protobuf-rust/src/c2se/member_bank_withdraw.rs <==
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub bank_name: ::prost::alloc::string::String,
  #[prost(string, tag = "2")]
  pub name: ::prost::alloc::string::String,
  #[prost(string, tag = "3")]
  pub account_number: ::prost::alloc::string::String,
  #[prost(uint32, tag = "4")]
  pub amount: u32,
  #[prost(string, tag = "5")]
  pub password: ::prost::alloc::string::String,
  #[prost(string, optional, tag = "6")]
  pub memo: ::core::option::Option<::prost::alloc::string::String>,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<create_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `CreateMemberBankWithdrawResponse`.
pub mod create_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsRequest {
  #[prost(message, optional, tag = "1")]
  pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
  #[prost(message, repeated, tag = "2")]
  pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
  #[prost(message, optional, tag = "3")]
  pub search: ::core::option::Option<list_member_bank_withdraws_request::Search>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsRequest`.
pub mod list_member_bank_withdraws_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Search {
    #[prost(string, optional, tag = "1")]
    pub member_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "2")]
    pub bank_name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "3")]
    pub name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "4")]
    pub account_number_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(uint32, optional, tag = "5")]
    pub amount: ::core::option::Option<u32>,
    #[prost(string, optional, tag = "6")]
    pub memo_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(
      enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
      optional,
      tag = "7"
    )]
    pub state: ::core::option::Option<i32>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_member_bank_withdraws_response::Result>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsResponse`.
pub mod list_member_bank_withdraws_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub member_bank_withdraws:
      ::prost::alloc::vec::Vec<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<get_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `GetMemberBankWithdrawResponse`.
pub mod get_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
  #[prost(string, tag = "2")]
  pub bank_name: ::prost::alloc::string::String,
  #[prost(string, tag = "3")]
  pub name: ::prost::alloc::string::String,
  #[prost(string, tag = "4")]
  pub account_number: ::prost::alloc::string::String,
  #[prost(uint32, tag = "5")]
  pub amount: u32,
  #[prost(string, tag = "6")]
  pub password: ::prost::alloc::string::String,
  #[prost(string, optional, tag = "7")]
  pub memo: ::core::option::Option<::prost::alloc::string::String>,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawResponse`.
pub mod update_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
  #[prost(
    enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
    tag = "2"
  )]
  pub state: i32,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_for_state_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawForStateResponse`.
pub mod update_member_bank_withdraw_for_state_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<delete_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `DeleteMemberBankWithdrawResponse`.
pub mod delete_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {}
}

==> v0.1.91-snapshot.tar.gz: beteran-protobuf-rust/src/c2se/member_bank_withdraw.rs <==
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub bank_name: ::prost::alloc::string::String,
  #[prost(string, tag = "2")]
  pub name: ::prost::alloc::string::String,
  #[prost(string, tag = "3")]
  pub account_number: ::prost::alloc::string::String,
  #[prost(double, tag = "4")]
  pub amount: f64,
  #[prost(string, tag = "5")]
  pub password: ::prost::alloc::string::String,
  #[prost(string, optional, tag = "6")]
  pub memo: ::core::option::Option<::prost::alloc::string::String>,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<create_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `CreateMemberBankWithdrawResponse`.
pub mod create_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsRequest {
  #[prost(message, optional, tag = "1")]
  pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
  #[prost(message, repeated, tag = "2")]
  pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
  #[prost(message, optional, tag = "3")]
  pub search: ::core::option::Option<list_member_bank_withdraws_request::Search>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsRequest`.
pub mod list_member_bank_withdraws_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Search {
    #[prost(string, optional, tag = "1")]
    pub member_id: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "2")]
    pub bank_name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "3")]
    pub name_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(string, optional, tag = "4")]
    pub account_number_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(double, optional, tag = "5")]
    pub amount: ::core::option::Option<f64>,
    #[prost(string, optional, tag = "6")]
    pub memo_like: ::core::option::Option<::prost::alloc::string::String>,
    #[prost(
      enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
      optional,
      tag = "7"
    )]
    pub state: ::core::option::Option<i32>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_member_bank_withdraws_response::Result>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsResponse`.
pub mod list_member_bank_withdraws_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub member_bank_withdraws:
      ::prost::alloc::vec::Vec<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<get_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `GetMemberBankWithdrawResponse`.
pub mod get_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
  #[prost(string, tag = "2")]
  pub bank_name: ::prost::alloc::string::String,
  #[prost(string, tag = "3")]
  pub name: ::prost::alloc::string::String,
  #[prost(string, tag = "4")]
  pub account_number: ::prost::alloc::string::String,
  #[prost(double, tag = "5")]
  pub amount: f64,
  #[prost(string, tag = "6")]
  pub password: ::prost::alloc::string::String,
  #[prost(string, optional, tag = "7")]
  pub memo: ::core::option::Option<::prost::alloc::string::String>,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawResponse`.
pub mod update_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
  #[prost(
    enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
    tag = "2"
  )]
  pub state: i32,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_for_state_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawForStateResponse`.
pub mod update_member_bank_withdraw_for_state_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawRequest {
  #[prost(string, tag = "1")]
  pub id: ::prost::alloc::string::String,
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<delete_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `DeleteMemberBankWithdrawResponse`.
pub mod delete_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {}
}
